[easytag/wip/unstable: 13/56] Use "image" instead of "picture" in the UI



commit 82c41ba3e47c6da17e50def13451deede3d4276e
Author: Ekaterina Gerasimova <kittykat3756 gmail com>
Date:   Sat Apr 6 23:52:59 2013 +0100

    Use "image" instead of "picture" in the UI
    
    Replace all instances of "picture" with "image" in the UI.
    
    Remove the redundant "Pictures:" label next to the images tree view,
    move the "apply to all" button below the tree view, alongside the other
    buttons, and give it an insert-image icon.

 src/easytag.c  |   63 ++++++++++++++++++++++++--------------------------------
 src/easytag.h  |    1 -
 src/et_core.c  |   10 ++++----
 src/flac_tag.c |    2 +-
 src/picture.c  |   44 ++++++++++++++++++++++++---------------
 src/prefs.c    |    2 +-
 6 files changed, 61 insertions(+), 61 deletions(-)
---
diff --git a/src/easytag.c b/src/easytag.c
index f656997..bf50c49 100644
--- a/src/easytag.c
+++ b/src/easytag.c
@@ -1078,27 +1078,21 @@ Create_Tag_Area (void)
     /*
      * 2 - Page for extra tag fields
      */
-    Label = gtk_label_new(_("Pictures")); // As there is only the picture field... - also used in 
ET_Display_File_Tag_To_UI
+    Label = gtk_label_new (_("Images")); // As there is only the picture field... - also used in 
ET_Display_File_Tag_To_UI
     Frame = gtk_frame_new(NULL);
     gtk_notebook_append_page(GTK_NOTEBOOK(TagNoteBook),Frame,Label);
     gtk_container_set_border_width(GTK_CONTAINER(Frame), 0);
     gtk_frame_set_shadow_type(GTK_FRAME(Frame),GTK_SHADOW_NONE); // Hide the Frame
 
-    Table = et_grid_new (3, 5);
+    Table = et_grid_new (1, 2);
     gtk_container_add(GTK_CONTAINER(Frame),Table);
     gtk_container_set_border_width(GTK_CONTAINER(Table),2);
 
-    /* Picture */
-    PictureLabel = gtk_label_new(_("Pictures:"));
-    et_grid_attach_full (GTK_GRID (Table), PictureLabel, 0, 0, 1, 1, FALSE,
-                         FALSE, TablePadding, TablePadding);
-    gtk_misc_set_alignment(GTK_MISC(PictureLabel),1,0.5);
-
     // Scroll window for PictureEntryView
     PictureScrollWindow = gtk_scrolled_window_new(NULL, NULL);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(PictureScrollWindow),
                                    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    et_grid_attach_full (GTK_GRID (Table), PictureScrollWindow, 1, 0, 3, 1,
+    et_grid_attach_full (GTK_GRID (Table), PictureScrollWindow, 0, 0, 1, 1,
                          TRUE, TRUE, TablePadding, TablePadding);
 
     PictureEntryModel = gtk_list_store_new(PICTURE_COLUMN_COUNT,
@@ -1110,7 +1104,8 @@ Create_Tag_Area (void)
     gtk_container_add(GTK_CONTAINER(PictureScrollWindow), PictureEntryView);
     gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(PictureEntryView), FALSE);
     gtk_widget_set_size_request(PictureEntryView, -1, 200);
-    gtk_widget_set_tooltip_text(PictureEntryView,_("You can use drag and drop to add picture."));
+    gtk_widget_set_tooltip_text (PictureEntryView,
+                                 _("You can use drag and drop to add an image"));
 
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(PictureEntryView));
     gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
@@ -1143,52 +1138,56 @@ Create_Tag_Area (void)
     g_signal_connect(G_OBJECT(PictureEntryView), 
"button_press_event",G_CALLBACK(Picture_Entry_View_Button_Pressed),NULL);
     g_signal_connect(G_OBJECT(PictureEntryView),"key_press_event", 
G_CALLBACK(Picture_Entry_View_Key_Pressed),NULL);
 
-    // The mini button for picture
-    PictureMButton = gtk_button_new();
-    et_grid_attach_full (GTK_GRID (Table), PictureMButton, 4, 0, 1, 1, FALSE,
-                         FALSE, TablePadding, TablePadding);
-    gtk_widget_set_size_request(PictureMButton,MButtonSize,MButtonSize);
-    g_signal_connect(G_OBJECT(PictureMButton),"clicked",G_CALLBACK(Mini_Button_Clicked),NULL);
-    gtk_widget_set_tooltip_text(PictureMButton,_("Tag selected files with these pictures"));
-
     // Picture action buttons
     hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
-    et_grid_attach_full (GTK_GRID (Table), hbox, 1, 1, 3, 1, FALSE, FALSE,
+    et_grid_attach_full (GTK_GRID (Table), hbox, 0, 1, 1, 1, FALSE, FALSE,
                          TablePadding, TablePadding);
 
     PictureAddButton = gtk_button_new();
     Icon = gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_SMALL_TOOLBAR);
     gtk_container_add(GTK_CONTAINER(PictureAddButton),Icon);
     gtk_box_pack_start(GTK_BOX(hbox),PictureAddButton,FALSE,FALSE,0);
-    gtk_widget_set_tooltip_text(PictureAddButton,_("Add pictures to the tag (drag and drop is also 
available)."));
+    gtk_widget_set_tooltip_text (PictureAddButton,
+                                 _("Add images to the tag"));
 
     PictureClearButton = gtk_button_new();
     Icon = gtk_image_new_from_stock(GTK_STOCK_REMOVE, GTK_ICON_SIZE_SMALL_TOOLBAR);
     gtk_container_add(GTK_CONTAINER(PictureClearButton),Icon);
     gtk_box_pack_start(GTK_BOX(hbox),PictureClearButton,FALSE,FALSE,0);
-    gtk_widget_set_tooltip_text(PictureClearButton,_("Remove selected pictures, else all pictures."));
-
-    Label = gtk_label_new("   ");
-    gtk_box_pack_start(GTK_BOX(hbox),Label,FALSE,FALSE,0);
+    gtk_widget_set_tooltip_text (PictureClearButton,
+                                 _("Remove selected images"));
 
     PictureSaveButton = gtk_button_new();
     Icon = gtk_image_new_from_stock(GTK_STOCK_SAVE, GTK_ICON_SIZE_SMALL_TOOLBAR);
     gtk_container_add(GTK_CONTAINER(PictureSaveButton),Icon);
     gtk_box_pack_start(GTK_BOX(hbox),PictureSaveButton,FALSE,FALSE,0);
     gtk_widget_set_sensitive(GTK_WIDGET(PictureSaveButton), FALSE);
-    gtk_widget_set_tooltip_text(PictureSaveButton,_("Save the selected pictures on the hard disk."));
+    gtk_widget_set_tooltip_text (PictureSaveButton,
+                                 _("Save the selected images to files"));
 
     PicturePropertiesButton = gtk_button_new();
     Icon = gtk_image_new_from_stock(GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_SMALL_TOOLBAR);
     gtk_container_add(GTK_CONTAINER(PicturePropertiesButton),Icon);
     gtk_box_pack_start(GTK_BOX(hbox),PicturePropertiesButton,FALSE,FALSE,0);
     gtk_widget_set_sensitive(GTK_WIDGET(PicturePropertiesButton), FALSE);
-    gtk_widget_set_tooltip_text(PicturePropertiesButton,_("Set properties of the selected pictures."));
+    gtk_widget_set_tooltip_text (PicturePropertiesButton,
+                                 _("Edit image properties"));
+
+    PictureMButton = gtk_button_new ();
+    Icon = gtk_image_new_from_icon_name ("insert-image",
+                                         GTK_ICON_SIZE_SMALL_TOOLBAR);
+    gtk_container_add (GTK_CONTAINER (PictureMButton), Icon);
+    gtk_box_pack_start (GTK_BOX (hbox), PictureMButton, FALSE, FALSE,
+                        0);
+    gtk_widget_set_tooltip_text (PictureMButton,
+                                 _("Tag selected files with these images"));
 
     g_signal_connect(G_OBJECT(PictureClearButton),      "clicked", G_CALLBACK(Picture_Clear_Button_Clicked), 
NULL);
     g_signal_connect(G_OBJECT(PictureAddButton),        "clicked", G_CALLBACK(Picture_Add_Button_Clicked), 
NULL);
     g_signal_connect(G_OBJECT(PictureSaveButton),       "clicked", G_CALLBACK(Picture_Save_Button_Clicked), 
NULL);
     g_signal_connect(G_OBJECT(PicturePropertiesButton), "clicked", 
G_CALLBACK(Picture_Properties_Button_Clicked), NULL);
+    g_signal_connect (G_OBJECT (PictureMButton), "clicked",
+                      G_CALLBACK (Mini_Button_Clicked), NULL);
 
     // Activate Drag'n'Drop for the PictureAddButton (and PictureEntryView)
     gtk_drag_dest_set(GTK_WIDGET(PictureAddButton),
@@ -1654,9 +1653,9 @@ Mini_Button_Clicked (GObject *object)
             etfilelist = g_list_next(etfilelist);
         }
         if (res)
-            msg = g_strdup(_("Selected files tagged with pictures."));
+            msg = g_strdup (_("Selected files tagged with images."));
         else
-            msg = g_strdup(_("Removed pictures from selected files."));
+            msg = g_strdup (_("Removed images from selected files."));
         Picture_Free(res);
     }
 
@@ -4208,7 +4207,6 @@ void Tag_Area_Display_Controls (ET_File *ETFile)
                 gtk_widget_hide(GTK_WIDGET(URLEntry));
                 gtk_widget_hide(GTK_WIDGET(EncodedByLabel));
                 gtk_widget_hide(GTK_WIDGET(EncodedByEntry));
-                gtk_widget_hide(GTK_WIDGET(PictureLabel));
                 gtk_widget_hide(GTK_WIDGET(PictureScrollWindow));
                 gtk_widget_hide(GTK_WIDGET(PictureMButton));
                 gtk_widget_hide(GTK_WIDGET(PictureClearButton));
@@ -4229,7 +4227,6 @@ void Tag_Area_Display_Controls (ET_File *ETFile)
                 gtk_widget_show(GTK_WIDGET(URLEntry));
                 gtk_widget_show(GTK_WIDGET(EncodedByLabel));
                 gtk_widget_show(GTK_WIDGET(EncodedByEntry));
-                gtk_widget_show(GTK_WIDGET(PictureLabel));
                 gtk_widget_show(GTK_WIDGET(PictureScrollWindow));
                 gtk_widget_show(GTK_WIDGET(PictureMButton));
                 gtk_widget_show(GTK_WIDGET(PictureClearButton));
@@ -4253,7 +4250,6 @@ void Tag_Area_Display_Controls (ET_File *ETFile)
             gtk_widget_show(GTK_WIDGET(URLEntry));
             gtk_widget_show(GTK_WIDGET(EncodedByLabel));
             gtk_widget_show(GTK_WIDGET(EncodedByEntry));
-            gtk_widget_show(GTK_WIDGET(PictureLabel));
             gtk_widget_show(GTK_WIDGET(PictureScrollWindow));
             gtk_widget_show(GTK_WIDGET(PictureMButton));
             gtk_widget_show(GTK_WIDGET(PictureClearButton));
@@ -4277,7 +4273,6 @@ void Tag_Area_Display_Controls (ET_File *ETFile)
             gtk_widget_show(GTK_WIDGET(URLEntry));
             gtk_widget_show(GTK_WIDGET(EncodedByLabel));
             gtk_widget_show(GTK_WIDGET(EncodedByEntry));
-            gtk_widget_show(GTK_WIDGET(PictureLabel));
             gtk_widget_show(GTK_WIDGET(PictureScrollWindow));
             gtk_widget_show(GTK_WIDGET(PictureMButton));
             gtk_widget_show(GTK_WIDGET(PictureClearButton));
@@ -4300,7 +4295,6 @@ void Tag_Area_Display_Controls (ET_File *ETFile)
             gtk_widget_show(GTK_WIDGET(URLEntry));
             gtk_widget_show(GTK_WIDGET(EncodedByLabel));
             gtk_widget_show(GTK_WIDGET(EncodedByEntry));
-            gtk_widget_hide(GTK_WIDGET(PictureLabel));
             gtk_widget_hide(GTK_WIDGET(PictureScrollWindow));
             gtk_widget_hide(GTK_WIDGET(PictureMButton));
             gtk_widget_hide(GTK_WIDGET(PictureClearButton));
@@ -4323,7 +4317,6 @@ void Tag_Area_Display_Controls (ET_File *ETFile)
             gtk_widget_hide(GTK_WIDGET(URLEntry));
             gtk_widget_hide(GTK_WIDGET(EncodedByLabel));
             gtk_widget_hide(GTK_WIDGET(EncodedByEntry));
-            gtk_widget_hide(GTK_WIDGET(PictureLabel));
             gtk_widget_hide(GTK_WIDGET(PictureScrollWindow));
             gtk_widget_hide(GTK_WIDGET(PictureMButton));
             gtk_widget_hide(GTK_WIDGET(PictureClearButton));
@@ -4347,7 +4340,6 @@ void Tag_Area_Display_Controls (ET_File *ETFile)
             gtk_widget_show(GTK_WIDGET(URLEntry));
             gtk_widget_show(GTK_WIDGET(EncodedByLabel));
             gtk_widget_show(GTK_WIDGET(EncodedByEntry));
-            gtk_widget_hide(GTK_WIDGET(PictureLabel));
             gtk_widget_hide(GTK_WIDGET(PictureScrollWindow));
             gtk_widget_hide(GTK_WIDGET(PictureMButton));
             gtk_widget_hide(GTK_WIDGET(PictureClearButton));
@@ -4371,7 +4363,6 @@ void Tag_Area_Display_Controls (ET_File *ETFile)
             gtk_widget_hide(GTK_WIDGET(URLEntry));
             gtk_widget_hide(GTK_WIDGET(EncodedByLabel));
             gtk_widget_hide(GTK_WIDGET(EncodedByEntry));
-            gtk_widget_hide(GTK_WIDGET(PictureLabel));
             gtk_widget_hide(GTK_WIDGET(PictureScrollWindow));
             gtk_widget_hide(GTK_WIDGET(PictureMButton));
             gtk_widget_hide(GTK_WIDGET(PictureClearButton));
diff --git a/src/easytag.h b/src/easytag.h
index 8534cf8..cca039c 100644
--- a/src/easytag.h
+++ b/src/easytag.h
@@ -107,7 +107,6 @@ GtkWidget    *OrigArtistLabel;
 GtkWidget    *CopyrightLabel;
 GtkWidget    *URLLabel;
 GtkWidget    *EncodedByLabel;
-GtkWidget    *PictureLabel;
 // Mini buttons
 GtkWidget    *TrackMButtonSequence;
 GtkWidget    *TrackMButtonNbrFiles;
diff --git a/src/flac_tag.c b/src/flac_tag.c
index 0792cd4..f85b40b 100644
--- a/src/flac_tag.c
+++ b/src/flac_tag.c
@@ -670,7 +670,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 //pic->height = p->height;
                 //pic->width  = p->width;
 
-                //g_print("Picture type : %s\n",FLAC__StreamMetadata_Picture_TypeString[p->type]);
+                //g_print("Image type : %s\n",FLAC__StreamMetadata_Picture_TypeString[p->type]);
                 //g_print("Mime    type : %s\n",p->mime_type);
 
                 break;
diff --git a/src/picture.c b/src/picture.c
index 67d0269..d65f4f7 100644
--- a/src/picture.c
+++ b/src/picture.c
@@ -296,7 +296,7 @@ void Picture_Add_Button_Clicked (GObject *object)
     }
 
 
-    FileSelectionWindow = gtk_file_chooser_dialog_new(_("Add pictures"),
+    FileSelectionWindow = gtk_file_chooser_dialog_new(_("Add images"),
                                                       parent_window,
                                                       GTK_FILE_CHOOSER_ACTION_OPEN,
                                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -420,7 +420,8 @@ void Picture_Properties_Button_Clicked (GObject *object)
         if (valid)
             gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, PICTURE_COLUMN_DATA, &pic, -1);
 
-        title = g_strdup_printf(_("Picture Properties %d/%d"),selection_i++,selection_nbr);
+        title = g_strdup_printf (_("Image Properties %d/%d"), selection_i++,
+                                 selection_nbr);
         PictureTypesWindow = gtk_dialog_new_with_buttons(title,
                                                          parent_window,
                                                          GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -442,7 +443,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
         renderer = gtk_cell_renderer_text_new();
         column = gtk_tree_view_column_new();
         gtk_tree_view_column_pack_start(column, renderer, FALSE);
-        gtk_tree_view_column_set_title(column, _("Picture Type"));
+        gtk_tree_view_column_set_title (column, _("Image Type"));
         gtk_tree_view_column_set_attributes(column, renderer,
                                             "text", PICTURE_TYPE_COLUMN_TEXT,
                                             NULL);
@@ -499,7 +500,7 @@ void Picture_Properties_Button_Clicked (GObject *object)
         gtk_tree_path_free(rowPath);
 
         // Description of the picture
-        label = gtk_label_new(_("Picture Description:"));
+        label = gtk_label_new (_("Image Description:"));
         
gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(PictureTypesWindow))),label,FALSE,FALSE,4);
 
         // Entry for the description
@@ -617,7 +618,8 @@ void Picture_Save_Button_Clicked (GObject *object)
         if (valid)
             gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, PICTURE_COLUMN_DATA, &pic, -1);
 
-        title = g_strdup_printf(_("Save picture %d/%d"),selection_i++,selection_nbr);
+        title = g_strdup_printf (_("Save image %d/%d"), selection_i++,
+                                 selection_nbr);
         FileSelectionWindow = gtk_file_chooser_dialog_new(title,
                                                           parent_window,
                                                           GTK_FILE_CHOOSER_ACTION_SAVE,
@@ -834,7 +836,7 @@ Picture_Type_String (EtPictureType type)
         
         case ET_PICTURE_TYPE_UNDEFINED:
         default:
-            return _("Unknown picture type");
+            return _("Unknown image type");
     }
 }
 
@@ -990,16 +992,19 @@ void PictureEntry_Update (Picture *pic, gboolean select_it)
                 
                 g_object_unref(loader);
                 
-                Log_Print(LOG_ERROR,"%s",_("Cannot display the picture, as not enough data has been read to 
determine how to create the image buffer."));
+                Log_Print (LOG_ERROR, "%s",
+                           _("Cannot display the image because not enough data has been read to determine 
how to create the image buffer."));
 
                 msgdialog = gtk_message_dialog_new(GTK_WINDOW(MainWindow),
                                                    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                                    GTK_MESSAGE_ERROR,
                                                    GTK_BUTTONS_CLOSE,
                                                    "%s",
-                                                   _("Cannot display the picture"));
-                gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(msgdialog),_("Not enough data 
has been read to determine how to create the image buffer"));
-                gtk_window_set_title(GTK_WINDOW(msgdialog),_("Load Picture File"));
+                                                   _("Cannot display the image"));
+                gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (msgdialog),
+                                                          _("Not enough data has been read to determine how 
to create the image buffer."));
+                gtk_window_set_title (GTK_WINDOW (msgdialog),
+                                      _("Load Image File"));
                 gtk_dialog_run(GTK_DIALOG(msgdialog));
                 gtk_widget_destroy(msgdialog);
             }
@@ -1097,7 +1102,8 @@ Picture_Load_File_Data (const gchar *filename)
 
     if (stat(filename, &st)==-1)
     {
-        Log_Print(LOG_ERROR,_("Picture file not loaded (%s)…"),g_strerror(errno));
+        Log_Print (LOG_ERROR, _("Image file not loaded (%s)…"),
+                   g_strerror(errno));
 #ifdef G_OS_WIN32
         g_free(filename);
 #endif /* G_OS_WIN32 */
@@ -1122,11 +1128,12 @@ Picture_Load_File_Data (const gchar *filename)
                                            _("Cannot open file: '%s'"),
                                            filename_utf8);
         gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(msgdialog),"%s",g_strerror(errno));
-        gtk_window_set_title(GTK_WINDOW(msgdialog),_("Picture File Error"));
+        gtk_window_set_title (GTK_WINDOW (msgdialog), _("Image File Error"));
         gtk_dialog_run(GTK_DIALOG(msgdialog));
         gtk_widget_destroy(msgdialog);
 
-        Log_Print(LOG_ERROR,_("Picture file not loaded (%s)…"),g_strerror(errno));
+        Log_Print (LOG_ERROR, _("Image file not loaded (%s)…"),
+                   g_strerror(errno));
         g_free (buffer);
         g_free(filename_utf8);
 #ifdef G_OS_WIN32
@@ -1146,7 +1153,8 @@ Picture_Load_File_Data (const gchar *filename)
         if (buffer)
             g_free(buffer);
         
-        Log_Print(LOG_ERROR,_("Picture file not loaded (%s)…"),g_strerror(errno));
+        Log_Print (LOG_ERROR, _("Image file not loaded (%s)…"),
+                   g_strerror(errno));
 
         return NULL;
     }else
@@ -1158,7 +1166,7 @@ Picture_Load_File_Data (const gchar *filename)
         pic->size = size;
         pic->data = (guchar *)buffer;
 
-        Log_Print(LOG_OK,_("Picture file loaded…"));
+        Log_Print (LOG_OK, _("Image file loaded…"));
 
         return pic;
     }
@@ -1175,14 +1183,16 @@ Picture_Save_File_Data (const Picture *pic, const gchar *filename)
     fd = open(filename, O_WRONLY|O_CREAT|O_TRUNC, 0666);
     if (fd == -1)
     {
-        Log_Print(LOG_ERROR,_("Picture file can't be saved (%s)…"),g_strerror(errno));
+        Log_Print (LOG_ERROR, _("Image file cannot be saved (%s)…"),
+                   g_strerror(errno));
         return FALSE;
     }
 
     if (write(fd, pic->data, pic->size) != pic->size)
     {
         close(fd);
-        Log_Print(LOG_ERROR,_("Picture file can't be saved (%s)…"),g_strerror(errno));
+        Log_Print (LOG_ERROR, _("Image file cannot be saved (%s)…"),
+                   g_strerror(errno));
         return FALSE;
     }
 
diff --git a/src/prefs.c b/src/prefs.c
index f34ed8c..9253fe9 100644
--- a/src/prefs.c
+++ b/src/prefs.c
@@ -674,7 +674,7 @@ void Open_OptionsWindow (void)
     gtk_grid_attach (GTK_GRID (Table), StripTagWhenEmptyFields, 0, 1, 1, 1);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(StripTagWhenEmptyFields),STRIP_TAG_WHEN_EMPTY_FIELDS);
     gtk_widget_set_tooltip_text(StripTagWhenEmptyFields,_("As ID3v2 tags may contain other data than "
-        "Title, Artist, Album, Year, Track, Genre or Comment (as an attached picture, lyrics…), "
+        "Title, Artist, Album, Year, Track, Genre or Comment (as an attached image, lyrics…), "
         "this option allows you to strip the whole tag when these seven standard data fields have "
         "been set to blank."));
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/et_core.c b/src/et_core.c
index 0d8f1a6..252c4ab 100644
--- a/src/et_core.c
+++ b/src/et_core.c
@@ -2953,9 +2953,9 @@ ET_Display_File_Tag_To_UI (ET_File *ETFile)
             pic = pic->next;
         }
 
         // Get page "Pictures" of the notebook
         page = gtk_notebook_get_nth_page(GTK_NOTEBOOK(TagNoteBook),1);
-        string = g_strdup_printf(_("Pictures (%d)"),nbr_pic);
+        string = g_strdup_printf (_("Images (%d)"), nbr_pic);
         // Update the notebook tab
         gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(TagNoteBook),page,string);
         // Update the notebook menu
@@ -2965,12 +2965,12 @@ ET_Display_File_Tag_To_UI (ET_File *ETFile)
     }else
     {
         GtkWidget *page;
         // Get page "Pictures" of the notebook
         page = gtk_notebook_get_nth_page(GTK_NOTEBOOK(TagNoteBook),1);
         // Update the notebook tab
-        gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(TagNoteBook),page,"Pictures");
+        gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(TagNoteBook),page,"Images");
         // Update the notebook menu
-        gtk_notebook_set_menu_label_text(GTK_NOTEBOOK(TagNoteBook),page,"Pictures");
+        gtk_notebook_set_menu_label_text(GTK_NOTEBOOK(TagNoteBook),page,"Images");
     }
 
     return TRUE;
@@ -2953,9 +2953,9 @@ ET_Display_File_Tag_To_UI (ET_File *ETFile)
         }
 
-        // Get page "Pictures" of the notebook
+        // Get page "Images" of the notebook
         page = gtk_notebook_get_nth_page(GTK_NOTEBOOK(TagNoteBook),1);
@@ -2965,12 +2965,12 @@ ET_Display_File_Tag_To_UI (ET_File *ETFile)
     {
         GtkWidget *page;
-        // Get page "Pictures" of the notebook
+        // Get page "Images" of the notebook
         page = gtk_notebook_get_nth_page(GTK_NOTEBOOK(TagNoteBook),1);
         // Update the notebook tab